@@ -12,7 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import base64
 import copy
 import errno
 import glob
@@ -27,6 +26,7 @@ import time
 from ironic_lib import utils as ironic_utils
 from oslo_concurrency import processutils
 from oslo_log import log as logging
+from oslo_serialization import base64
 from oslo_utils import units
 from six.moves.urllib import parse
 
@@ -361,7 +361,7 @@ def get_journalctl_output(lines=None, units=None):
 def gzip_and_b64encode(io_dict=None, file_list=None):
     """Gzip and base64 encode files and BytesIO buffers.
 
-    :param io_dict: A dictionary containg whose the keys are the file
+    :param io_dict: A dictionary containing whose the keys are the file
         names and the value a BytesIO object.
     :param file_list: A list of file path.
     :returns: A gzipped and base64 encoded string.
@@ -383,7 +383,7 @@ def gzip_and_b64encode(io_dict=None, file_list=None):
                 tar.add(f)
 
         fp.seek(0)
-        return base64.b64encode(fp.getvalue())
+        return base64.encode_as_bytes(fp.getvalue())
 
 
 def collect_system_logs(journald_max_lines=None):
@@ -416,3 +416,20 @@ def collect_system_logs(journald_max_lines=None):
         try_get_command_output(io_dict, name, cmd)
 
     return gzip_and_b64encode(io_dict=io_dict, file_list=file_list)
+
+
+def get_ssl_client_options(conf):
+    """Format SSL-related requests options.
+
+    :param conf: oslo_config CONF object
+    :returns: tuple of 'verify' and 'cert' values to pass to requests
+    """
+    if conf.insecure:
+        verify = False
+    else:
+        verify = conf.cafile or True
+    if conf.certfile and conf.keyfile:
+        cert = (conf.certfile, conf.keyfile)
+    else:
+        cert = None
+    return verify, cert
